@@ -1,241 +1,5 @@
 r'''
-# aws-openapigateway-lambda module
-
-<!--BEGIN STABILITY BANNER-->---
-
-
-![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
-
----
-<!--END STABILITY BANNER-->
-
-| **Reference Documentation**:| <span style="font-weight: normal">https://docs.aws.amazon.com/solutions/latest/constructs/</span>|
-|:-------------|:-------------|
-
-<div style="height:8px"></div>
-
-| **Language**     | **Package**        |
-|:-------------|-----------------|
-|![Python Logo](https://docs.aws.amazon.com/cdk/api/latest/img/python32.png) Python|`aws_solutions_constructs.aws_openapigateway_lambda`|
-|![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-openapigateway-lambda`|
-|![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.openapigatewaylambda`|
-
-## Overview
-
-This AWS Solutions Construct implements an Amazon API Gateway REST API defined by an OpenAPI specification file connected to an AWS Lambda function.
-
-Here is a minimal deployable pattern definition.
-
-**NOTE** The referenced `openapi/apiDefinition.yaml` openapi definition file and `messages-lambda` lambda package directory for the three code samples below can both be found under this constructs `test` folder (`<repository_root>/source/patterns/@aws-solutions-constructs/aws-openapigateway-lambda/test`)
-
-Typescript
-
-```python
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { Construct } from 'constructs';
-import { OpenApiGatewayToLambda } from '@aws-solutions-constructs/aws-openapigateway-lambda';
-import { Asset } from 'aws-cdk-lib/aws-s3-assets';
-import * as path from 'path';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-
-const apiDefinitionAsset = new Asset(this, 'ApiDefinitionAsset', {
-  path: path.join(__dirname, 'openapi/apiDefinition.yaml')
-});
-
-new OpenApiGatewayToLambda(this, 'OpenApiGatewayToLambda', {
-  apiDefinitionAsset,
-  apiIntegrations: [
-    {
-      id: 'MessagesHandler',
-      lambdaFunctionProps: {
-        runtime: lambda.Runtime.NODEJS_18_X,
-        handler: 'index.handler',
-        code: lambda.Code.fromAsset(`${__dirname}/messages-lambda`),
-      }
-    }
-  ]
-});
-```
-
-Python
-
-```python
-from aws_cdk import (
-    Stack,
-    aws_s3_assets as s3_assets,
-    aws_lambda as lambda_,
-)
-from constructs import Construct
-from aws_solutions_constructs.aws_openapigateway_lambda import OpenApiGatewayToLambda, ApiIntegration
-
-class TestStack(Stack):
-
-    def __init__(self, scope: Construct, construct_id: str, **kwargs) -> None:
-        super().__init__(scope, construct_id, **kwargs)
-
-        api_definition_asset = s3_assets.Asset(self, "ApiDefinitionAsset", path="./openapi/apiDefinition.yaml")
-
-        api_integration = ApiIntegration(id="MessagesHandler", lambda_function_props={
-            "runtime": lambda_.Runtime.NODEJS_18_X,
-            "handler": "index.handler",
-            "code": lambda_.Code.from_asset("./messages-lambda")
-        })
-
-        openapigateway_to_lambda = OpenApiGatewayToLambda(self,
-            id="OpenApiGatewayToLambda",
-            api_integrations=[api_integration],
-            api_definition_asset=api_definition_asset
-        )
-```
-
-Java
-
-```java
-import software.amazon.awscdk.services.lambda.Code;
-import software.amazon.awscdk.services.lambda.FunctionProps;
-import software.amazon.awscdk.services.s3.assets.Asset;
-import software.amazon.awscdk.services.s3.assets.AssetProps;
-import software.amazon.awsconstructs.services.openapigatewaylambda.ApiIntegration;
-import software.amazon.awsconstructs.services.openapigatewaylambda.OpenApiGatewayToLambda;
-import software.amazon.awsconstructs.services.openapigatewaylambda.OpenApiGatewayToLambdaProps;
-import software.constructs.Construct;
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-
-import java.util.Collections;
-
-import static software.amazon.awscdk.services.lambda.Runtime.NODEJS_18_X;
-
-final Asset apiDefinitionAsset = new Asset(this, "ApiDefinition", AssetProps.builder().path("openapi/apiDefinition.yaml").build());
-
-final ApiIntegration apiIntegration = ApiIntegration.builder()
-    .id("MessagesHandler")
-    .lambdaFunctionProps(new FunctionProps.Builder()
-        .runtime(NODEJS_18_X)
-        .code(Code.fromAsset("messages-lambda"))
-        .handler("index.handler")
-        .build())
-    .build();
-
-new OpenApiGatewayToLambda(this, "OpenApiGatewayToLambda", OpenApiGatewayToLambdaProps.builder()
-    .apiDefinitionAsset(apiDefinitionAsset)
-    .apiIntegrations(Collections.singletonList(apiIntegration))
-    .build());
-```
-
-## Pattern Construct Props
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|apiGatewayProps?|[`apigateway.RestApiBaseProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.RestApiBaseProps.html)|Optional user-provided props to override the default props for the API.|
-|apiDefinitionBucket?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3.IBucket.html)|S3 Bucket where the OpenAPI spec file is located. When specifying this property, `apiDefinitionKey` must also be specified.|
-|apiDefinitionKey?|`string`|S3 Object name of the OpenAPI spec file. When specifying this property, `apiDefinitionBucket` must also be specified.|
-|apiDefinitionAsset?|[`aws_s3_assets.Asset`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_s3_assets.Asset.html)|Local file asset of the OpenAPI spec file.|
-|apiIntegrations|`ApiIntegration[]`|One or more key-value pairs that contain an id for the api integration and either an existing lambda function or an instance of the LambdaProps. Please see the `Overview of how the OpenAPI file transformation works` section below for more usage details.|
-|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
-
-## Pattern Properties
-
-| **Name**     | **Type**        | **Description** |
-|:-------------|:----------------|-----------------|
-|apiLambdaFunctions|`ApiLambdaFunction[]`|Returns an array of ApiLambdaFunction objects, where each has an `id` of the `apiIntegration` and the corresponding `lambda.Function` that it maps to.|
-|apiGateway|[`api.SpecRestApi`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_apigateway.SpecRestApi.html)|Returns an instance of the API Gateway REST API created by the pattern.|
-|apiGatewayCloudWatchRole?|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iam.Role.html)|Returns an instance of the iam.Role created by the construct for API Gateway for CloudWatch access.|
-|apiGatewayLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for API Gateway access logging to CloudWatch.|
-
-## Overview of how the OpenAPI file transformation works
-
-This construct automatically transforms an incoming OpenAPI Definition (residing locally or in S3) by auto-populating the `uri` fields of the `x-amazon-apigateway-integration` integrations with the resolved value of the backing lambda functions. It does so by allowing the user to specify the `apiIntegrations` property and then correlates it with the api definition.
-
-Looking at an example - a user creates an instantiation of `apiIntegrations` that specifies one integration named `MessagesHandler` that passes in a set of `lambda.FunctionProps` and a second integration named `PhotosHandler` that passes in an existing `lambda.Function`:
-
-```python
-const apiIntegrations: ApiIntegration[] = [
-  {
-    id: 'MessagesHandler',
-    lambdaFunctionProps: {
-      runtime: lambda.Runtime.NODEJS_18_X,
-      handler: 'index.handler',
-      code: lambda.Code.fromAsset(`${__dirname}/messages-lambda`),
-    }
-  },
-  {
-    id: 'PhotosHandler',
-    existingLambdaObj: new lambda.Function(this, 'PhotosLambda', {
-      runtime: lambda.Runtime.NODEJS_18_X,
-      handler: 'index.handler',
-      code: lambda.Code.fromAsset(`${__dirname}/photos-lambda`),
-    })
-  }
-]
-```
-
-And a corresponding api definition with `GET` and `POST` methods on a `/messages` resource and a `GET` method on a `/photos` resource.
-
-```
-openapi: "3.0.1"
-info:
-  title: "api"
-  version: "2023-02-20T20:46:08Z"
-paths:
-  /messages:
-    get:
-      x-amazon-apigateway-integration:
-        httpMethod: "POST"
-        uri: MessagesHandler
-        passthroughBehavior: "when_no_match"
-        type: "aws_proxy"
-    post:
-      x-amazon-apigateway-integration:
-        httpMethod: "POST"
-        uri: MessagesHandler
-        passthroughBehavior: "when_no_match"
-        type: "aws_proxy"
-  /photos:
-    get:
-      x-amazon-apigateway-integration:
-        httpMethod: "POST"
-        uri: PhotosHandler
-        passthroughBehavior: "when_no_match"
-        type: "aws_proxy"
-```
-
-When the construct is created or updated, it will overwrite the `MessagesHandler` string with the fully resolved lambda proxy uri of the `MessagesHandlerLambdaFunction`, e.g., `arn:${Aws.PARTITION}:apigateway:${Aws.REGION}:lambda:path/2015-03-31/functions/${messagesLambda.functionArn}/invocations`, and similarly for the `PhotosHandler` string and `PhotosHandlerLambdaFunction`, resulting in a valid OpenAPI spec file that is then passed to the `SpecRestApi` construct.
-
-For more information on specifying an API with OpenAPI, please see the [OpenAPI Specification](https://spec.openapis.org/oas/latest.html)
-
-## ApiIntegration Details
-
-This construct defines a custom type, `ApiIntegration`, that is specified as a required prop. The type has a required property, `id`, and two optional properties `existingLambdaObj` and `lambdaFunctionProps`. The `id` property is used to map the corresponding lambda function being defined with the placeholder string in the OpenAPI template file, and is not a CDK construct ID. Exactly one of `existingLambdaObj` or `lambdaFunctionProps` must be specified or the construct will throw an error.
-
-## Default settings
-
-Out of the box implementation of the Construct without any override will set the following defaults:
-
-### Amazon API Gateway
-
-* Deploy an edge-optimized API endpoint
-* Enable CloudWatch logging for API Gateway
-* Configure least privilege access IAM role for API Gateway
-* Enable X-Ray Tracing
-
-### AWS Lambda Function
-
-* Configure limited privilege access IAM roles for Lambda functions
-* Enable reusing connections with Keep-Alive for NodeJs Lambda functions
-* Enable X-Ray Tracing
-* Set Environment Variables
-
-  * AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
-
-## Architecture
-
-![Architecture Diagram](architecture.png)
-
----
-
-
-© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+Documentation for this pattern can be found [here](https://github.com/awslabs/aws-solutions-constructs/blob/main/source/patterns/%40aws-solutions-constructs/aws-openapigateway-lambda/README.adoc)
 '''
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
@@ -250,7 +14,22 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
+import typeguard
+from importlib.metadata import version as _metadata_package_version
+TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])
+
+def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
+    if TYPEGUARD_MAJOR_VERSION <= 2:
+        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
+    else:
+        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
+           pass
+        else:
+            if TYPEGUARD_MAJOR_VERSION == 3:
+                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
+                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
+            else:
+                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore
 
 from ._jsii import *
 
@@ -278,7 +57,7 @@ class ApiIntegration:
         self,
         *,
         id: builtins.str,
-        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_lambda_obj: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.Function, _aws_cdk_aws_lambda_ceddda9d.Alias]] = None,
         lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''The ApiIntegration interface is used to correlate a user-specified id with either a existing lambda function or set of lambda props.
@@ -317,13 +96,13 @@ class ApiIntegration:
     @builtins.property
     def existing_lambda_obj(
         self,
-    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
+    ) -> typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.Function, _aws_cdk_aws_lambda_ceddda9d.Alias]]:
         '''The Lambda function to associate with the API method in the OpenAPI file matched by id.
 
         One and only one of existingLambdaObj or lambdaFunctionProps must be specified, any other combination will cause an error.
         '''
         result = self._values.get("existing_lambda_obj")
-        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
+        return typing.cast(typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.Function, _aws_cdk_aws_lambda_ceddda9d.Alias]], result)
 
     @builtins.property
     def lambda_function_props(
@@ -351,28 +130,38 @@ class ApiIntegration:
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-openapigateway-lambda.ApiLambdaFunction",
     jsii_struct_bases=[],
-    name_mapping={"id": "id", "lambda_function": "lambdaFunction"},
+    name_mapping={
+        "id": "id",
+        "function_alias": "functionAlias",
+        "lambda_function": "lambdaFunction",
+    },
 )
 class ApiLambdaFunction:
     def __init__(
         self,
         *,
         id: builtins.str,
-        lambda_function: _aws_cdk_aws_lambda_ceddda9d.Function,
+        function_alias: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Alias] = None,
+        lambda_function: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
     ) -> None:
         '''Helper object to map an ApiIntegration id to its resolved lambda.Function. This type is exposed as a property on the instantiated construct.
 
         :param id: Id of the ApiIntegration, used to correlate this lambda function to the api integration in the open api definition.
-        :param lambda_function: The instantiated lambda.Function.
+        :param function_alias: -
+        :param lambda_function: The function the API method will integrate with - Must be defined in lambdaFunction or functionAlias (but not both).
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__7b34df00db45a414bf2a2dd0aa85c226040b27bc33e6b02e652a7c94c036c86c)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument function_alias", value=function_alias, expected_type=type_hints["function_alias"])
             check_type(argname="argument lambda_function", value=lambda_function, expected_type=type_hints["lambda_function"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "id": id,
-            "lambda_function": lambda_function,
         }
+        if function_alias is not None:
+            self._values["function_alias"] = function_alias
+        if lambda_function is not None:
+            self._values["lambda_function"] = lambda_function
 
     @builtins.property
     def id(self) -> builtins.str:
@@ -382,11 +171,15 @@ class ApiLambdaFunction:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
-        '''The instantiated lambda.Function.'''
+    def function_alias(self) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Alias]:
+        result = self._values.get("function_alias")
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Alias], result)
+
+    @builtins.property
+    def lambda_function(self) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
+        '''The function the API method will integrate with - Must be defined in lambdaFunction or functionAlias (but not both).'''
         result = self._values.get("lambda_function")
-        assert result is not None, "Required property 'lambda_function' is missing"
-        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -413,6 +206,7 @@ class OpenApiGatewayToLambda(
         api_integrations: typing.Sequence[typing.Union[ApiIntegration, typing.Dict[builtins.str, typing.Any]]],
         api_definition_asset: typing.Optional[_aws_cdk_aws_s3_assets_ceddda9d.Asset] = None,
         api_definition_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+        api_definition_json: typing.Any = None,
         api_definition_key: typing.Optional[builtins.str] = None,
         api_gateway_props: typing.Optional[typing.Union[_aws_cdk_aws_apigateway_ceddda9d.RestApiBaseProps, typing.Dict[builtins.str, typing.Any]]] = None,
         internal_transform_memory_size: typing.Optional[jsii.Number] = None,
@@ -425,6 +219,7 @@ class OpenApiGatewayToLambda(
         :param api_integrations: One or more key-value pairs that contain an id for the api integration and either an existing lambda function or an instance of the LambdaProps. Example: const apiIntegrations: ApiIntegration[] = [ { id: 'MessagesHandler', lambdaFunctionProps: { runtime: defaults.COMMERCIAL_REGION_LAMBDA_NODE_RUNTIME, handler: 'index.handler', code: lambda.Code.fromAsset(``${__dirname}/messages-lambda``), } }, { id: 'PhotosHandler', existingLambdaObj: new lambda.Function(this, 'PhotosLambda', { runtime: defaults.COMMERCIAL_REGION_LAMBDA_NODE_RUNTIME, handler: 'index.handler', code: lambda.Code.fromAsset(``${__dirname}/photos-lambda``), }) } ]
         :param api_definition_asset: Local file asset of the OpenAPI spec file.
         :param api_definition_bucket: S3 Bucket where the OpenAPI spec file is located. When specifying this property, apiDefinitionKey must also be specified.
+        :param api_definition_json: OpenAPI specification represented in a JSON object to be embedded in the CloudFormation template. IMPORTANT - Including the spec in the template introduces a risk of the template growing too big, but there are some use cases that require an embedded spec. Unless your use case explicitly requires an embedded spec you should pass your spec as an S3 asset.
         :param api_definition_key: S3 Object name of the OpenAPI spec file. When specifying this property, apiDefinitionBucket must also be specified.
         :param api_gateway_props: Optional user-provided props to override the default props for the API. Default: - Default props are used.
         :param internal_transform_memory_size: Optional user-defined memory size for the Lambda function custom resource installed to do the OpenAPI definition transformation. This setting does not affect the deployed architecture - only the ability for the Construct to complete its work. Defaults to 1024 MiB, but for larger files (hundreds of megabytes or gigabytes in size) this value may need to be increased. Default: 1024
@@ -439,6 +234,7 @@ class OpenApiGatewayToLambda(
             api_integrations=api_integrations,
             api_definition_asset=api_definition_asset,
             api_definition_bucket=api_definition_bucket,
+            api_definition_json=api_definition_json,
             api_definition_key=api_definition_key,
             api_gateway_props=api_gateway_props,
             internal_transform_memory_size=internal_transform_memory_size,
@@ -478,6 +274,7 @@ class OpenApiGatewayToLambda(
         "api_integrations": "apiIntegrations",
         "api_definition_asset": "apiDefinitionAsset",
         "api_definition_bucket": "apiDefinitionBucket",
+        "api_definition_json": "apiDefinitionJson",
         "api_definition_key": "apiDefinitionKey",
         "api_gateway_props": "apiGatewayProps",
         "internal_transform_memory_size": "internalTransformMemorySize",
@@ -492,6 +289,7 @@ class OpenApiGatewayToLambdaProps:
         api_integrations: typing.Sequence[typing.Union[ApiIntegration, typing.Dict[builtins.str, typing.Any]]],
         api_definition_asset: typing.Optional[_aws_cdk_aws_s3_assets_ceddda9d.Asset] = None,
         api_definition_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+        api_definition_json: typing.Any = None,
         api_definition_key: typing.Optional[builtins.str] = None,
         api_gateway_props: typing.Optional[typing.Union[_aws_cdk_aws_apigateway_ceddda9d.RestApiBaseProps, typing.Dict[builtins.str, typing.Any]]] = None,
         internal_transform_memory_size: typing.Optional[jsii.Number] = None,
@@ -502,6 +300,7 @@ class OpenApiGatewayToLambdaProps:
         :param api_integrations: One or more key-value pairs that contain an id for the api integration and either an existing lambda function or an instance of the LambdaProps. Example: const apiIntegrations: ApiIntegration[] = [ { id: 'MessagesHandler', lambdaFunctionProps: { runtime: defaults.COMMERCIAL_REGION_LAMBDA_NODE_RUNTIME, handler: 'index.handler', code: lambda.Code.fromAsset(``${__dirname}/messages-lambda``), } }, { id: 'PhotosHandler', existingLambdaObj: new lambda.Function(this, 'PhotosLambda', { runtime: defaults.COMMERCIAL_REGION_LAMBDA_NODE_RUNTIME, handler: 'index.handler', code: lambda.Code.fromAsset(``${__dirname}/photos-lambda``), }) } ]
         :param api_definition_asset: Local file asset of the OpenAPI spec file.
         :param api_definition_bucket: S3 Bucket where the OpenAPI spec file is located. When specifying this property, apiDefinitionKey must also be specified.
+        :param api_definition_json: OpenAPI specification represented in a JSON object to be embedded in the CloudFormation template. IMPORTANT - Including the spec in the template introduces a risk of the template growing too big, but there are some use cases that require an embedded spec. Unless your use case explicitly requires an embedded spec you should pass your spec as an S3 asset.
         :param api_definition_key: S3 Object name of the OpenAPI spec file. When specifying this property, apiDefinitionBucket must also be specified.
         :param api_gateway_props: Optional user-provided props to override the default props for the API. Default: - Default props are used.
         :param internal_transform_memory_size: Optional user-defined memory size for the Lambda function custom resource installed to do the OpenAPI definition transformation. This setting does not affect the deployed architecture - only the ability for the Construct to complete its work. Defaults to 1024 MiB, but for larger files (hundreds of megabytes or gigabytes in size) this value may need to be increased. Default: 1024
@@ -517,6 +316,7 @@ class OpenApiGatewayToLambdaProps:
             check_type(argname="argument api_integrations", value=api_integrations, expected_type=type_hints["api_integrations"])
             check_type(argname="argument api_definition_asset", value=api_definition_asset, expected_type=type_hints["api_definition_asset"])
             check_type(argname="argument api_definition_bucket", value=api_definition_bucket, expected_type=type_hints["api_definition_bucket"])
+            check_type(argname="argument api_definition_json", value=api_definition_json, expected_type=type_hints["api_definition_json"])
             check_type(argname="argument api_definition_key", value=api_definition_key, expected_type=type_hints["api_definition_key"])
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
             check_type(argname="argument internal_transform_memory_size", value=internal_transform_memory_size, expected_type=type_hints["internal_transform_memory_size"])
@@ -529,6 +329,8 @@ class OpenApiGatewayToLambdaProps:
             self._values["api_definition_asset"] = api_definition_asset
         if api_definition_bucket is not None:
             self._values["api_definition_bucket"] = api_definition_bucket
+        if api_definition_json is not None:
+            self._values["api_definition_json"] = api_definition_json
         if api_definition_key is not None:
             self._values["api_definition_key"] = api_definition_key
         if api_gateway_props is not None:
@@ -587,6 +389,17 @@ class OpenApiGatewayToLambdaProps:
         result = self._values.get("api_definition_bucket")
         return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket], result)
 
+    @builtins.property
+    def api_definition_json(self) -> typing.Any:
+        '''OpenAPI specification represented in a JSON object to be embedded in the CloudFormation template.
+
+        IMPORTANT - Including the spec in the template introduces a risk of the template growing too big, but
+        there are some use cases that require an embedded spec. Unless your use case explicitly requires an embedded spec
+        you should pass your spec as an S3 asset.
+        '''
+        result = self._values.get("api_definition_json")
+        return typing.cast(typing.Any, result)
+
     @builtins.property
     def api_definition_key(self) -> typing.Optional[builtins.str]:
         '''S3 Object name of the OpenAPI spec file.
@@ -668,7 +481,7 @@ publication.publish()
 def _typecheckingstub__9b1a09e9bbf57f6b9c31a7e98f3c22bf1f14ee32a481f88b7c6a5dae44c51063(
     *,
     id: builtins.str,
-    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_lambda_obj: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.Function, _aws_cdk_aws_lambda_ceddda9d.Alias]] = None,
     lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
 ) -> None:
     """Type checking stubs"""
@@ -677,7 +490,8 @@ def _typecheckingstub__9b1a09e9bbf57f6b9c31a7e98f3c22bf1f14ee32a481f88b7c6a5dae4
 def _typecheckingstub__7b34df00db45a414bf2a2dd0aa85c226040b27bc33e6b02e652a7c94c036c86c(
     *,
     id: builtins.str,
-    lambda_function: _aws_cdk_aws_lambda_ceddda9d.Function,
+    function_alias: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Alias] = None,
+    lambda_function: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -689,6 +503,7 @@ def _typecheckingstub__f72b11c0dbf5d67e28186e991bb77d43c6063fb3d69758a2d112ff6a5
     api_integrations: typing.Sequence[typing.Union[ApiIntegration, typing.Dict[builtins.str, typing.Any]]],
     api_definition_asset: typing.Optional[_aws_cdk_aws_s3_assets_ceddda9d.Asset] = None,
     api_definition_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    api_definition_json: typing.Any = None,
     api_definition_key: typing.Optional[builtins.str] = None,
     api_gateway_props: typing.Optional[typing.Union[_aws_cdk_aws_apigateway_ceddda9d.RestApiBaseProps, typing.Dict[builtins.str, typing.Any]]] = None,
     internal_transform_memory_size: typing.Optional[jsii.Number] = None,
@@ -703,6 +518,7 @@ def _typecheckingstub__2cf1c5fb01583839f606ad44a970067741d586951b8ec3e6b0a23aa04
     api_integrations: typing.Sequence[typing.Union[ApiIntegration, typing.Dict[builtins.str, typing.Any]]],
     api_definition_asset: typing.Optional[_aws_cdk_aws_s3_assets_ceddda9d.Asset] = None,
     api_definition_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+    api_definition_json: typing.Any = None,
     api_definition_key: typing.Optional[builtins.str] = None,
     api_gateway_props: typing.Optional[typing.Union[_aws_cdk_aws_apigateway_ceddda9d.RestApiBaseProps, typing.Dict[builtins.str, typing.Any]]] = None,
     internal_transform_memory_size: typing.Optional[jsii.Number] = None,
